Struct googapis::google::cloud::datacatalog::v1::CloudSqlBigQueryConnectionSpec [−][src]
pub struct CloudSqlBigQueryConnectionSpec {
pub instance_id: String,
pub database: String,
pub type: i32,
}Expand description
Specification for the BigQuery connection to a Cloud SQL instance.
Fields
instance_id: StringCloud SQL instance ID in the format of project:location:instance.
database: StringDatabase name.
type: i32Type of the Cloud SQL database.
Implementations
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sets type to the provided enum value.