Struct googapis::google::cloud::datacatalog::v1::CrossRegionalSource [−][src]
pub struct CrossRegionalSource {
pub taxonomy: String,
}Expand description
Cross-regional source used to import an existing taxonomy into a different region.
Fields
taxonomy: StringRequired. The resource name of the source taxonomy to import.